@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0800';
+our $VERSION = '0.0801';
 
 use Moo;
 use strictures 2;
@@ -256,7 +256,7 @@ sub draw {
             text  => $chord_name,
             color => $BLACK,
             x     => $SPACE,
-            y     => $self->strings * $SPACE - $SPACE / 3,
+            y     => ($self->frets + 1) * $SPACE - $SPACE / 3,
             size  => $SPACE / 2,
             aa    => 1,
         );
@@ -424,7 +424,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0800
+version 0.0801
 
 =head1 SYNOPSIS
 
